Enum sn_messaging::node::NodeSystemCmd [−][src]
pub enum NodeSystemCmd {
RegisterWallet(PublicKey),
StorageFull {
node_id: PublicKey,
section: XorName,
},
ReplicateChunk(Blob),
RepublishChunk(Blob),
ProposeRewardPayout(RewardProposal),
AccumulateRewardPayout(RewardAccumulation),
ReceiveExistingData {
node_rewards: BTreeMap<XorName, (NodeAge, PublicKey)>,
user_wallets: BTreeMap<PublicKey, ActorHistory>,
metadata: DataExchange,
},
}Expand description
Cmds related to the running of a node.
Variants
RegisterWallet(PublicKey)Register a wallet for reward payouts.
Notify Elders on nearing max capacity
Show fields
ReplicateChunk(Blob)Replicate a given chunk at an Adult
RepublishChunk(Blob)Tells the Elders to re-publish a chunk in the data section
ProposeRewardPayout(RewardProposal)When new section key, all propose a reward payout.
AccumulateRewardPayout(RewardAccumulation)When proposal has been agreed, they all accumulate the reward payout.
Sent to all promoted nodes (also sibling if any) after a completed transition to a new constellation.
Show fields
Fields of ReceiveExistingData
node_rewards: BTreeMap<XorName, (NodeAge, PublicKey)>Age and reward wallets of registered nodes, keyed by node name.
user_wallets: BTreeMap<PublicKey, ActorHistory>Transfer histories
metadata: DataExchangeMetadata